@@ -22,6 +22,8 @@ from nbconvert.preprocessors import ExecutePreprocessor
 
 EXAMPLES = os.path.join(os.path.dirname(os.path.dirname(__file__)), "docs", "examples")
 
+SKIP = ("11-icoads.ipynb",)
+
 MARS = (
     "04-source-mars.ipynb",
     "04-source-mars.ipynb",
@@ -52,12 +54,19 @@ def notebooks_list():
     return sorted(notebooks)
 
 
+@pytest.mark.skipif(
+    int(os.environ.get("CLIMETLAB_SKIP_NOTEBOOKS_TESTS", 0)),
+    reason="CLIMETLAB_SKIP_NOTEBOOKS_TESTS not zero",
+)
 @pytest.mark.skipif(
     sys.platform == "win32", reason="Cannot execute notebookds on Windows"
 )
 @pytest.mark.parametrize("path", notebooks_list())
 def test_notebook(path):
 
+    if path in SKIP:
+        pytest.skip("Notebook marked as 'skip'")
+
     if path in MARS:
         if not os.path.exists(os.path.expanduser("~/.ecmwfapirc")):
             pytest.skip("No ~/.ecmwfapirc")
@@ -67,7 +76,7 @@ def test_notebook(path):
             pytest.skip("No ~/.cdsapirc")
 
     if path in TENSORFLOW:
-        if sys.version_info > (3, 8):
+        if sys.version_info >= (3, 9):
             pytest.skip("Tensorflow not yet ready on 3.9")
 
     with open(os.path.join(EXAMPLES, path)) as f:
